;; Generated package description from ebdb-gnorb.el  -*- no-byte-compile: t -*-
(define-package "ebdb-gnorb" "1.0.2.0.20221221.75324" "Utilities for connecting EBDB to Gnorb" '((gnorb "1.1.0") (ebdb "0.2")) :commit "6201c59494309b2b8b04494bae7e76c7abfecca8" :url "https://elpa.gnu.org/packages/ebdb-gnorb.html" :authors '(("Eric Abrahamsen" . "eric@ericabrahamsen.net")) :maintainer '("Eric Abrahamsen" . "eric@ericabrahamsen.net"))
